@@ -4,19 +4,18 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
-from typing import List
-import ftd2xx
+__version__ = "0.0.8"
 
-from .base import BaseFlashable
-from .carts import BaseCard
-from .linkers import BaseLinker, linkers
-from .locales import _
-from .exceptions import *
-
-__version__ = "0.0.7"
-
-def get_connected_linkers(**kwargs):
+def get_connected_linkers():
 	# Get D2xx linkers
+	from typing import List
+
+	import ftd2xx
+
+	from .linkers import BaseLinker, linkers
+	from .locales import _
+	from .exceptions import clarify
+
 	num_devices = ftd2xx.createDeviceInfoList()
 	devices: List[BaseLinker] = []
 	for i in range(num_devices):
@@ -25,7 +24,7 @@ def get_connected_linkers(**kwargs):
 			dev = ftd2xx.open(i)
 		linker_cls = linkers.get(dev.description)
 		if linker_cls:
-			devices.append(linker_cls(dev, **kwargs))
+			devices.append(linker_cls(dev))
 		else:
 			dev.close()
 
