@@ -4,45 +4,28 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
-import sys
-
-if getattr(sys, "frozen", False):
-	from pathlib import Path
-	me = Path(sys.executable).absolute().parent
-	sys.path.append(str(me))
-
 import os
+import sys
 import tkinter as tk
 import traceback
 from tkinter import ttk
 from functools import partial
 from typing import  Dict, List, Tuple
 
-from . import themes
+from . import themes, resources
 from .i18n import _, TStringVar
 from .widgets import Menu, RichText, ScrollFrame
 from .components import (
 	add_progress, make_status, open_about, refresh_linkers, set_status,
 	GameList, HelpDialog, PreferencesDialog
 )
-from .. import __version__, logger
-from ..config import config
-
-
-try:
-	from appdirs import user_log_dir
-except ImportError:
-	# Portable version
-	import sys
-	def user_log_dir(appname=None, appauthor=None, version=None, opinion: bool = True):
-		base = os.path.join(os.path.dirname(sys.argv[0]), "logs")
-		if version:
-			return os.path.join(base, version)
-		return base
+from .. import logger
+from ..config import config, log_dir as error_log_dir
 
 
 logger.view = "gui"
 
+
 root = tk.Tk()
 
 title_var = TStringVar(_("window.title"))
@@ -140,7 +123,6 @@ log_handler = logger.Handler(logger.INFO, raw_handler=add_log_entry)
 log_handler.set_formatter(logger.nice_formatter)
 logger.add_handler(log_handler)
 
-error_log_dir = user_log_dir("pm2hw", None, __version__)
 error_log_dn = os.path.join(error_log_dir, "error.log")
 os.makedirs(error_log_dir, exist_ok=True)
 def error_log_writer(s):
@@ -192,6 +174,11 @@ with Menu(root) as m:
 				title=str(_("window.help.title"))
 			)
 		)
+		help.add_command(
+			labelvar=TStringVar(_("window.menu.help.check-for-updates")),
+			command=resources.prompt_update
+		)
+		help.add_separator()
 		help.add_command(labelvar=TStringVar(_("window.menu.help.about")), command=partial(open_about, root))
 
 def auto_refresh():
@@ -199,6 +186,17 @@ def auto_refresh():
 	root.after(5000, auto_refresh)
 auto_refresh()
 
+# Check if update script exists and delete
+if getattr(sys, "frozen", False):
+	from pathlib import Path
+	script: Path = Path(sys.executable).absolute() / "update.ps1"
+	try:
+		script.unlink()
+	except FileNotFoundError:
+		resources.prompt_update(False)
+else:
+	resources.prompt_update(False)
+
 # from .linker import DittoFlash
 # from .. import BaseLinker
 
