@@ -25,6 +25,7 @@ class ColorizedTheme(BaseTheme):
 	outside: ClassVar[Color]
 	inside: ClassVar[Color]
 	inset: ClassVar[Color]
+	highlight: ClassVar[Color]
 	console: ClassVar[Color]
 	selected: ClassVar[Color]
 	link: ClassVar[LinkColor]
@@ -125,6 +126,14 @@ class ColorizedTheme(BaseTheme):
 					"highlightbackground": self.outside.bg,
 				}
 			}),
+			ovr("HelpNumber.TLabel", {
+				"configure": {
+					"font": "RichTextH1Font",
+					"background": self.outside.bg,
+					"foreground": self.highlight.fg,
+					"highlightbackground": self.outside.bg,
+				}
+			}),
 			ovr("TLabelframe", {
 				"configure": {
 					"background": self.outside.bg,
